<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Supongo</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Que se encuentran</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <source>Missed</source>
        <translation>Perdidas</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Éxito</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Fin del juego</translation>
    </message>
    <message numerus="yes">
        <source>%1 of %n point(s)</source>
        <translation>
            <numerusform>%1 de %n punto</numerusform>
            <numerusform>%1 de %n puntos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>3 of %n point(s)</source>
        <translation>
            <numerusform>3 de %n punto</numerusform>
            <numerusform>3 de %n puntos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>2 of %n point(s)</source>
        <translation>
            <numerusform>2 de %n punto</numerusform>
            <numerusform>2 de %n puntos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>1 of %n point(s)</source>
        <translation>
            <numerusform>1 de %n punto</numerusform>
            <numerusform>1 de %n puntos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>0 of %n point(s)</source>
        <translation>
            <numerusform>0 de %n punto</numerusform>
            <numerusform>0 de %n puntos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n punto</numerusform>
            <numerusform>%n puntos</numerusform>
        </translation>
    </message>
    <message>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation>La puntuación máxima se calcula a partir de los siguientes treinta palabras:</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>m:ss</source>
        <translation>m:ss</translation>
    </message>
    <message numerus="yes">
        <source>%n guesses(s)</source>
        <translation>
            <numerusform>%n sugerencia</numerusform>
            <numerusform>%n sugerencias</numerusform>
        </translation>
    </message>
    <message>
        <source>+%1</source>
        <translation>+%1</translation>
    </message>
    <message numerus="yes">
        <source>%n strike(s)</source>
        <translation>
            <numerusform>%n acierto</numerusform>
            <numerusform>%n aciertos</numerusform>
        </translation>
    </message>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>Clásico</translation>
    </message>
    <message>
        <source>Refill</source>
        <translation>Rellenar</translation>
    </message>
    <message>
        <source>Stamina</source>
        <translation>Aguante</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Tachado</translation>
    </message>
    <message>
        <source>Allotment</source>
        <translation>Asignación</translation>
    </message>
    <message>
        <source>Discipline</source>
        <translation>Disciplina</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation>Cuenta atrás de 30 segundos y aumenta en aciertos.</translation>
    </message>
    <message>
        <source>Counts down from 3 minutes.</source>
        <translation>Cuenta atrás de 3 minutos.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation>Cuenta atrás de 30 segundos y recargas de aciertos.</translation>
    </message>
    <message>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation>Cuenta atrás de 45 segundos y se detiene en aciertos.</translation>
    </message>
    <message>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation>El juego termina después de 3 suposiciones incorrectas.</translation>
    </message>
    <message>
        <source>Game ends after 30 guesses.</source>
        <translation>El juego termina después de 30 intentos.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation>Cuenta atrás de 30 segundos y aumenta o disminuye en conjeturas.</translation>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <source>Unable to read dice from file.</source>
        <translation>No se puede leer dados de archivo.</translation>
    </message>
    <message>
        <source>Unable to read word list from file.</source>
        <translation>No se puede leer la lista de palabras de un archivo.</translation>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <source>Board Language</source>
        <translation>Idioma del tablero</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Elegir ...</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation>&lt;b&gt;Nota:&lt;/b&gt; Los cambios tendrán efecto cuando se empiece una nueva partida.</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Idioma:</translation>
    </message>
    <message>
        <source>Dice:</source>
        <translation>Dado:</translation>
    </message>
    <message>
        <source>Word list:</source>
        <translation>Lista de palabras:</translation>
    </message>
    <message>
        <source>Dictionary:</source>
        <translation>Diccionario:</translation>
    </message>
    <message>
        <source>Choose Dice File</source>
        <translation>Dice Elija Archivo</translation>
    </message>
    <message>
        <source>Choose Word List File</source>
        <translation>Escoje un fichero con la lista de palabras</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleccione el idioma de la aplicación:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del Sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Por favor, reinicie la aplicación para el cambio de idioma tenga efecto.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nuevo Juego</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Cantidad de palabras:</translation>
    </message>
    <message>
        <source>Minimum Word Length:</source>
        <translation>Longitud mínima de palabra:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Bajo</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alto</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Aleatorio</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n letra</numerusform>
            <numerusform>%n letras</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Las puntuaciones más altas</translation>
    </message>
    <message>
        <source>&lt;b&gt;Name&lt;/b&gt;</source>
        <translation>&lt;b&gt;Nombre&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Score&lt;/b&gt;</source>
        <translation>&lt;b&gt;Puntuación&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Date&lt;/b&gt;</source>
        <translation>&lt;b&gt;Fecha&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
        <translation>&lt;b&gt;Cronómetro&lt;/b&gt;</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Clear high scores?</source>
        <translation>¿Borrar puntuaciones más altas?</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Pausa&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click para continuar la partida.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Por favor espere&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Cargando juego...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Haga clic para empezar una partida nueva.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Por favor espere&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generando un nuevo tablero...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Por favor espere&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizando la lista de palabras...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Juego</translation>
    </message>
    <message>
        <source>New &amp;Game...</source>
        <translation>Nuevo &amp;Juego...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;New Roll</source>
        <translation>&amp;Nuevo Tablero</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Escoje...</translation>
    </message>
    <message>
        <source>&amp;Share...</source>
        <translation>&amp;Comparte...</translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>&amp;Fin</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Detalles</translation>
    </message>
    <message>
        <source>&amp;High Scores</source>
        <translation>&amp;Puntuaciones más altas</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Preferencias</translation>
    </message>
    <message>
        <source>Show &amp;Maximum Score</source>
        <translation>Mostrar &amp;Puntuacion Máxima</translation>
    </message>
    <message>
        <source>&amp;Never</source>
        <translation>&amp;Nunca</translation>
    </message>
    <message>
        <source>&amp;End Of Game</source>
        <translation>&amp;Fin del juego</translation>
    </message>
    <message>
        <source>&amp;Always</source>
        <translation>&amp;Siempre</translation>
    </message>
    <message>
        <source>Show Missed &amp;Words</source>
        <translation>Mostrar palabras &amp;perdidas</translation>
    </message>
    <message>
        <source>Show Word &amp;Counts</source>
        <translation>Mostrar &amp;Recuento de palabras</translation>
    </message>
    <message>
        <source>&amp;Board Language...</source>
        <translation>Idioma del &amp;tablero</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Idioma de la aplicación</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Controles</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>About &amp;Hspell</source>
        <translation>Acerca de &amp;Hspell</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;SCOWL</source>
        <translation>Acerca de &amp;SCOWL</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Tanglet %1</source>
        <translation>Tanglet %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation>Una variante de &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt; de un solo jugador</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Distribuido bajo la licencia &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</translation>
    </message>
    <message>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation>Lista de palabras inglesas basada en &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</translation>
    </message>
    <message>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation>Lista de palabras hebreas basada en &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</translation>
    </message>
    <message>
        <source>About Hspell</source>
        <translation>Acerca de Hspell</translation>
    </message>
    <message>
        <source>About SCOWL</source>
        <translation>Acerca de SCOWL</translation>
    </message>
    <message>
        <source>Import Game</source>
        <translation>Importar Juego</translation>
    </message>
    <message>
        <source>Tanglet Games (*.tanglet)</source>
        <translation>Tanglet Games (*.tanglet)</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>No se puede iniciar solicitado juego.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Export Game</source>
        <translation>Exportar Juego</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Finaliza el juego actual?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>Board Size:</source>
        <translation>Tamaño del tablero:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Grande</translation>
    </message>
    <message>
        <source>Word Density:</source>
        <translation>Densidad de palabras:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Longitud de palabras:</translation>
    </message>
    <message>
        <source>%1 or more letters</source>
        <translation>%1 o más letras</translation>
    </message>
    <message>
        <source>Game Type:</source>
        <translation>Tipo de juego:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descripción:</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controles</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Juegon con el ratón:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selecciona una palabra:&lt;/b&gt; Click en las letras de una palabra.&lt;br&gt;&lt;b&gt;Haz una sugerencia:&lt;/b&gt; Click en la última letras seleccionada.&lt;br&gt;&lt;b&gt;Borrar letras:&lt;/b&gt; Click en una letra seleccionada previamente.&lt;br&gt;&lt;b&gt;Borrar la palabra:&lt;/b&gt; Click dos veces en la primera letra seleccionada.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Juego con el teclado:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Selecciona una palabra:&lt;/b&gt; Teclea las letras de una palabra.&lt;br&gt;&lt;b&gt;Haz una sugerencia:&lt;/b&gt; Presiona Enter.&lt;br&gt;&lt;b&gt;Borra la palabra:&lt;/b&gt; Presiona Ctrl+Backspace.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <source>Letters:</source>
        <translation>Letras:</translation>
    </message>
    <message>
        <source>Found:</source>
        <translation>Encontradas:</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation>%1&lt;br&gt;%2/%3</translation>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n punto</numerusform>
            <numerusform>%n puntos</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Word finding game</source>
        <translation>Juego de encontrar palabras</translation>
    </message>
    <message>
        <source>A game file to play.</source>
        <translation>Un archivo de juego para jugar.</translation>
    </message>
</context>
</TS>
